@@ -1,16 +1,17 @@
+from __future__ import annotations
+
 import os
 import subprocess
 import sys
 from shutil import which
-from typing import Optional
 
 
 class GitIsNotInstalled(Exception):
     pass
 
 
-class AozoraCloner():
-    url = 'https://github.com/aozorabunko/aozorabunko'
+class AozoraCloner:
+    url = "https://github.com/aozorabunko/aozorabunko"
 
     def __init__(self) -> None:
         pass
@@ -24,20 +25,20 @@ class AozoraCloner():
         cls.url = url
 
     @classmethod
-    def clone(cls) -> Optional[int]:
-        if not which('git'):
+    def clone(cls) -> int | None:
+        if not which("git"):
             raise GitIsNotInstalled
         else:
-            p = subprocess.Popen('git clone --depth 1 ' + cls.url, shell=True)
+            p = subprocess.Popen("git clone --depth 1 " + cls.url, shell=True)
             p.wait()
             return p.poll()
 
 
-if __name__ == '__main__':
-    REPO = os.path.join(os.getcwd(), 'aozorabunko')
+if __name__ == "__main__":
+    REPO = os.path.join(os.getcwd(), "aozorabunko")
 
-    if os.path.isdir(REPO) and os.path.isdir(os.path.join(REPO, '.git')):
-        print('aozorabunko already exists!', file=sys.stderr)
+    if os.path.isdir(REPO) and os.path.isdir(os.path.join(REPO, ".git")):
+        print("aozorabunko already exists!", file=sys.stderr)
         exit(0)
     else:
         AozoraCloner().clone()
